==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ConfigBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConfigBuilder extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.Config,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigBuilder>{
  public ConfigBuilder() {
    this(false);
  }
  public ConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new Config(), validationEnabled);
  }
  public ConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Config(), validationEnabled);
  }
  public ConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.Config instance) {
    this(fluent, instance, false);
  }
  public ConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.Config instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.Config instance) {
    this(instance,false);
  }
  public ConfigBuilder(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.Config instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.Config build() {
    Config buildable = new Config(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConfigBuilder that = (ConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ConfigBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConfigBuilder extends ConfigFluentImpl<ConfigBuilder> implements VisitableBuilder<Config,ConfigBuilder>{
  public ConfigBuilder() {
    this(false);
  }
  public ConfigBuilder(Boolean validationEnabled) {
    this(new Config(), validationEnabled);
  }
  public ConfigBuilder(ConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigBuilder(ConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Config(), validationEnabled);
  }
  public ConfigBuilder(ConfigFluent<?> fluent,Config instance) {
    this(fluent, instance, false);
  }
  public ConfigBuilder(ConfigFluent<?> fluent,Config instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConfigBuilder(Config instance) {
    this(instance,false);
  }
  public ConfigBuilder(Config instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ConfigFluent<?> fluent;
  Boolean validationEnabled;
  public Config build() {
    Config buildable = new Config(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
